+++
title = "Single video"
tags = ["front-matter", "videos", "single"]
videos = ["video path with space.mp4"]
draft = false
+++

If a video path has spaces in it, wrap the whole path in double
quotes.
